@@ -1,14 +1,15 @@
 <?php
 
 /*
-  V4.21 20 Mar 2004  (c) 2000-2004 John Lim (jlim@natsoft.com.my). All rights reserved.
+  V4.52 10 Aug 2004  (c) 2000-2004 John Lim (jlim@natsoft.com.my). All rights reserved.
   Released under both BSD license and Lesser GPL library license. 
   Whenever there is any discrepancy between the two licenses, 
   the BSD license will take precedence.
   
   Set tabs to 4.
   
-  PHP5 Iterator Class:
+  Declares the ADODB Base Class for PHP5 "ADODB_BASE_RS", and supports iteration with 
+  the ADODB_Iterator class.
   
   		$rs = $db->Execute("select * from adoxyz");
 		foreach($rs as $k => $v) {
@@ -19,6 +20,7 @@
 	Iterator code based on http://cvs.php.net/cvs.php/php-src/ext/spl/examples/cachingiterator.inc?login=2
  */
  
+
  class ADODB_Iterator implements Iterator {
 
     private $rs;
@@ -56,12 +58,12 @@
 	{
 		return call_user_func_array(array($this->rs, $func), $params);
 	}
-	
-	function __toString()
-	{
-		return 'ADODB Iterator';
-	}
 
+	
+	function hasMore()
+	{
+		return !$this->rs->EOF;
+	}
 
 }
 
@@ -70,6 +72,12 @@ class ADODB_BASE_RS implements IteratorAggregate {
     function getIterator() {
         return new ADODB_Iterator($this);
     }
+	
+	function __toString()
+	{
+		include_once(ADODB_DIR.'/toexport.inc.php');
+		return _adodb_export($this,',',',',false,true);
+	}
 } 
 
 ?>
\ No newline at end of file
