@@ -1,11 +1,11 @@
 <?php
 /*
-V4.21 20 Mar 2004  (c) 2000-2004 John Lim (jlim@natsoft.com.my). All rights reserved.  
+V4.52 10 Aug 2004  (c) 2000-2004 John Lim (jlim@natsoft.com.my). All rights reserved.  
   Released under both BSD license and Lesser GPL library license. 
   Whenever there is any discrepancy between the two licenses, 
   the BSD license will take precedence.
 
-  Latest version is available at http://php.weblogs.com/
+  Latest version is available at http://adodb.sourceforge.net
   
   Interbase data driver. Requires interbase client. Works on Windows and Unix.
 
@@ -23,13 +23,17 @@ V4.21 20 Mar 2004  (c) 2000-2004 John Lim (jlim@natsoft.com.my). All rights rese
    $conn->Execute("insert into table (id, col1,...) values ($id, $val1,...)");
 */
 
+// security - hide paths
+if (!defined('ADODB_DIR')) die();
 
 class ADODB_ibase extends ADOConnection {
 	var $databaseType = "ibase";
 	var $dataProvider = "ibase";
 	var $replaceQuote = "''"; // string to use to replace quotes
-	var $ibase_timefmt = '%Y-%m-%d'; // For hours,mins,secs change to '%Y-%m-%d %H:%M:%S';
+	var $ibase_datefmt = '%Y-%m-%d'; // For hours,mins,secs change to '%Y-%m-%d %H:%M:%S';
 	var $fmtDate = "'Y-m-d'";
+	var $ibase_timestampfmt = "%Y-%m-%d %H:%M:%S";
+	var $ibase_timefmt = "%H:%M:%S";
 	var $fmtTimeStamp = "'Y-m-d, H:i:s'";
 	var $concat_operator='||';
 	var $_transactionID;
@@ -42,7 +46,7 @@ class ADODB_ibase extends ADOConnection {
 	var $_bindInputArray = true;
 	var $buffers = 0;
 	var $dialect = 1;
-	var $sysDate = "cast('TODAY' as date)";
+	var $sysDate = "cast('TODAY' as timestamp)";
 	var $sysTimeStamp = "cast('NOW' as timestamp)";
 	var $ansiOuter = true;
 	var $hasAffectedRows = false;
@@ -54,6 +58,45 @@ class ADODB_ibase extends ADOConnection {
 		 if (defined('IBASE_DEFAULT')) $this->ibasetrans = IBASE_DEFAULT;
   	}
 	
+	
+	   // returns true or false
+	function _connect($argHostname, $argUsername, $argPassword, $argDatabasename,$persist=false)
+	{  
+		if (!function_exists('ibase_pconnect')) return null;
+		if ($argDatabasename) $argHostname .= ':'.$argDatabasename;
+		$fn = ($persist) ? 'ibase_pconnect':'ibase_connect';
+		$this->_connectionID = $fn($argHostname,$argUsername,$argPassword,
+					$this->charSet,$this->buffers,$this->dialect);
+		
+		if ($this->dialect != 1) { // http://www.ibphoenix.com/ibp_60_del_id_ds.html
+			$this->replaceQuote = "''";
+		}
+		if ($this->_connectionID === false) {
+			$this->_handleerror();
+			return false;
+		}
+		
+		// PHP5 change.
+		if (function_exists('ibase_timefmt')) {
+			ibase_timefmt($this->ibase_datefmt,IBASE_DATE );
+			if ($this->dialect == 1) ibase_timefmt($this->ibase_datefmt,IBASE_TIMESTAMP );
+			else ibase_timefmt($this->ibase_timestampfmt,IBASE_TIMESTAMP );
+			ibase_timefmt($this->ibase_timefmt,IBASE_TIME );
+			
+		} else {
+			ini_set("ibase.timestampformat", $this->ibase_timestampfmt);
+			ini_set("ibase.dateformat", $this->ibase_datefmt);
+			ini_set("ibase.timeformat", $this->ibase_timefmt);
+		}
+		return true;
+	}
+	   // returns true or false
+	function _pconnect($argHostname, $argUsername, $argPassword, $argDatabasename)
+	{
+		return $this->_connect($argHostname, $argUsername, $argPassword, $argDatabasename,true);
+	}	
+	
+	
 	function MetaPrimaryKeys($table,$owner_notused=false,$internalKey=false)
 	{	
 		if ($internalKey) return array('RDB$DB_KEY');
@@ -109,6 +152,23 @@ class ADODB_ibase extends ADOConnection {
 		return $ret;
 	}
 	
+	// there are some compat problems with ADODB_COUNTRECS=false and $this->_logsql currently.
+	// it appears that ibase extension cannot support multiple concurrent queryid's
+	function &_Execute($sql,$inputarr=false) 
+	{
+	global $ADODB_COUNTRECS;
+	
+		if ($this->_logsql) {
+			$savecrecs = $ADODB_COUNTRECS;
+			$ADODB_COUNTRECS = true; // force countrecs
+			$ret =& ADOConnection::_Execute($sql,$inputarr);
+			$ADODB_COUNTRECS = $savecrecs;
+		} else {
+			$ret =& ADOConnection::_Execute($sql,$inputarr);
+		}
+		return $ret;
+	}
+	
 	function RollbackTrans()
 	{
 		if ($this->transOff) return true;
@@ -236,41 +296,6 @@ class ADODB_ibase extends ADOConnection {
 			return $this->_errorMsg;
 	}
 
-	   // returns true or false
-	function _connect($argHostname, $argUsername, $argPassword, $argDatabasename)
-	{  
-		if (!function_exists('ibase_pconnect')) return false;
-		if ($argDatabasename) $argHostname .= ':'.$argDatabasename;
-		$this->_connectionID = ibase_connect($argHostname,$argUsername,$argPassword,$this->charSet,$this->buffers,$this->dialect);
-	 	if ($this->dialect != 1) { // http://www.ibphoenix.com/ibp_60_del_id_ds.html
-			$this->replaceQuote = "''";
-		}
-		if ($this->_connectionID === false) {
-			$this->_handleerror();
-			return false;
-		}
-		
-		ibase_timefmt($this->ibase_timefmt);	
-		return true;
-	}
-	   // returns true or false
-	function _pconnect($argHostname, $argUsername, $argPassword, $argDatabasename)
-	{
-		if (!function_exists('ibase_pconnect')) return false;
-		if ($argDatabasename) $argHostname .= ':'.$argDatabasename;
-		$this->_connectionID = ibase_pconnect($argHostname,$argUsername,$argPassword,$this->charSet,$this->buffers,$this->dialect);
-		if ($this->dialect != 1) { // http://www.ibphoenix.com/ibp_60_del_id_ds.html
-			$this->replaceQuote = "''";
-		}
-		if ($this->_connectionID === false) {
-			$this->_handleerror();
-			return false;
-		}
-		
-		ibase_timefmt($this->ibase_timefmt);
-		return true;
-	}	
-	
 	function Prepare($sql)
 	{
 		$stmt = ibase_prepare($this->_connectionID,$sql);
@@ -293,7 +318,6 @@ class ADODB_ibase extends ADOConnection {
 		if (is_array($sql)) {
 			$fn = 'ibase_execute';
 			$sql = $sql[1];
-			
 			if (is_array($iarr)) {
 				if  (ADODB_PHPVER >= 0x4050) { // actually 4.0.4
 					if ( !isset($iarr[0]) ) $iarr[0] = ''; // PHP5 compat hack
@@ -318,7 +342,7 @@ class ADODB_ibase extends ADOConnection {
 		
 			if (is_array($iarr)) {	
 				if (ADODB_PHPVER >= 0x4050) { // actually 4.0.4
-					if ( !isset($iarr[0]) ) $iarr[0] = ''; // PHP5 compat hack
+					if (sizeof($iarr) == 0) $iarr[0] = ''; // PHP5 compat hack
 					$fnarr =& array_merge( array($conn,$sql) , $iarr);
 					$ret = call_user_func_array($fn,$fnarr);
 				} else {
@@ -350,7 +374,7 @@ class ADODB_ibase extends ADOConnection {
 	 }
 	
 	//OPN STUFF start
-	function _ConvertFieldType(&$fld, $ftype, $flen, $fscale, $fsubtype, $fprecision, $isInterbase6)
+	function _ConvertFieldType(&$fld, $ftype, $flen, $fscale, $fsubtype, $fprecision, $dialect3)
 	{
 		$fscale = abs($fscale);
 		$fld->max_length = $flen;
@@ -358,7 +382,7 @@ class ADODB_ibase extends ADOConnection {
 		switch($ftype){
 			case 7: 
 			case 8:
-				if ($isInterbase6) {
+				if ($dialect3) {
 				    switch($fsubtype){
 				    	case 0: 
 				    		$fld->type = ($ftype == 7 ? 'smallint' : 'integer');
@@ -385,7 +409,7 @@ class ADODB_ibase extends ADOConnection {
 				}
 				break;
 			case 16: 
-				if ($isInterbase6) {
+				if ($dialect3) {
 				    switch($fsubtype){
 				    	case 0: 
 				    		$fld->type = 'decimal';
@@ -421,16 +445,18 @@ class ADODB_ibase extends ADOConnection {
 				}
 				break;
 			case 35:
-				if ($isInterbase6) {
+				if ($dialect3) {
 				    $fld->type = 'timestamp';
 				} else {
 					$fld->type = 'date';
 				}
 				break;
 			case 12:
-			case 13:
 				$fld->type = 'date';
 				break;
+			case 13:
+				$fld->type = 'time';
+				break;
 			case 37:
 				$fld->type = 'varchar';
 				break;
@@ -461,13 +487,13 @@ class ADODB_ibase extends ADOConnection {
 
 			$retarr = array();
 			//OPN STUFF start
-			$isInterbase6 = ($this->dialect==3 ? true : false);
+			$dialect3 = ($this->dialect==3 ? true : false);
 			//OPN STUFF end
 			while (!$rs->EOF) { //print_r($rs->fields);
 				$fld = new ADOFieldObject();
 				$fld->name = trim($rs->fields[0]);
 				//OPN STUFF start
-				$this->_ConvertFieldType($fld, $rs->fields[7], $rs->fields[3], $rs->fields[4], $rs->fields[5], $rs->fields[6], $isInterbase6);
+				$this->_ConvertFieldType($fld, $rs->fields[7], $rs->fields[3], $rs->fields[4], $rs->fields[5], $rs->fields[6], $dialect3);
 				if (isset($rs->fields[1]) && $rs->fields[1]) {
 					$fld->not_null = true;
 				}				
@@ -666,7 +692,7 @@ class ADODB_ibase extends ADOConnection {
 		 Class Name: Recordset
 --------------------------------------------------------------------------------------*/
 
-class ADORecordset_ibase extends ADORecordSet 
+class ADORecordset_ibase extends ADORecordSet
 {
 
 	var $databaseType = "ibase";
@@ -678,7 +704,7 @@ class ADORecordset_ibase extends ADORecordSet
 	global $ADODB_FETCH_MODE;
 	
 			$this->fetchMode = ($mode === false) ? $ADODB_FETCH_MODE : $mode;
-			return $this->ADORecordSet($id);
+			$this->ADORecordSet($id);
 	}
 
 	/*		Returns: an object containing field information.
@@ -690,31 +716,47 @@ class ADORecordset_ibase extends ADORecordSet
 	{
 			 $fld = new ADOFieldObject;
 			 $ibf = ibase_field_info($this->_queryID,$fieldOffset);
-			 $fld->name = strtolower($ibf['alias']);
-			 if (empty($fld->name)) $fld->name = strtolower($ibf['name']);
+			 switch (ADODB_ASSOC_CASE) {
+			 case 2: // the default
+			 	$fld->name = ($ibf['alias']);
+				 if (empty($fld->name)) $fld->name = ($ibf['name']);
+				 break;
+			 case 0: 
+				 $fld->name = strtoupper($ibf['alias']);
+				 if (empty($fld->name)) $fld->name = strtoupper($ibf['name']);
+				 break;
+			 case 1: 
+			 	$fld->name = strtolower($ibf['alias']);
+				 if (empty($fld->name)) $fld->name = strtolower($ibf['name']);
+				 break;
+			 }
+			 
 			 $fld->type = $ibf['type'];
 			 $fld->max_length = $ibf['length'];
+			 
+			 /*       This needs to be populated from the metadata */ 
+			 $fld->not_null = false;
+			 $fld->has_default = false;
+			 $fld->default_value = 'null';
 			 return $fld;
 	}
 
 	function _initrs()
 	{
-			$this->_numOfRows = -1;
-			$this->_numOfFields = @ibase_num_fields($this->_queryID);
-			
-			// cache types for blob decode check
-			for ($i=0, $max = $this->_numOfFields; $i < $max; $i++) { 
-				$f1 = $this->FetchField($i); 
-				$this->_cacheType[] = $f1->type;
-			}				
+		$this->_numOfRows = -1;
+		$this->_numOfFields = @ibase_num_fields($this->_queryID);
+
+		// cache types for blob decode check
+		for ($i=0, $max = $this->_numOfFields; $i < $max; $i++) { 
+			$f1 = $this->FetchField($i); 
+			$this->_cacheType[] = $f1->type;
+		}				
 	}
 
 	function _seek($row)
 	{
 		return false;
 	}
-
-	
 	
 	function _fetch() 
 	{
@@ -768,7 +810,7 @@ class ADORecordset_ibase extends ADORecordSet
 			}
 		}
 		
-		 return $this->fields[$this->bind[strtoupper($colname)]];
+		return $this->fields[$this->bind[strtoupper($colname)]];
 		
 	}
 	
@@ -799,7 +841,7 @@ class ADORecordset_ibase extends ADORecordSet
 			   
 		case 'TIMESTAMP':
 		case 'DATE': return 'D';
-				
+		case 'TIME': return 'T';
 				//case 'T': return 'T';
 
 				//case 'L': return 'L';
