@@ -1,6 +1,6 @@
 <?php
 /*
-V4.21 20 Mar 2004  (c) 2000-2004 John Lim (jlim@natsoft.com.my). All rights reserved.
+V4.52 10 Aug 2004  (c) 2000-2004 John Lim (jlim@natsoft.com.my). All rights reserved.
   Released under both BSD license and Lesser GPL library license. 
   Whenever there is any discrepancy between the two licenses, 
   the BSD license will take precedence.
@@ -9,6 +9,9 @@ V4.21 20 Mar 2004  (c) 2000-2004 John Lim (jlim@natsoft.com.my). All rights rese
   Synonym for csv driver.
 */ 
 
+// security - hide paths
+if (!defined('ADODB_DIR')) die();
+
 if (! defined("_ADODB_PROXY_LAYER")) {
 	 define("_ADODB_PROXY_LAYER", 1 );
 	 include(ADODB_DIR."/drivers/adodb-csv.inc.php");
